@@ -19,9 +19,11 @@ import logging
 from datetime import datetime
 from typing import Dict
 
-from src.load_shedding import ScheduleError
-from src.load_shedding.providers.eskom import Eskom, Province, Stage, Suburb
-from src.load_shedding.providers import Provider, ProviderError
+from providers.eskom import Province, Stage, Suburb, Provider, ProviderError
+
+
+class ScheduleError(Exception):
+    pass
 
 
 def get_suburb_schedule(provider: Provider, province: Province, suburb: Suburb, cached: bool = True) -> Dict[Stage, list]:
@@ -73,14 +75,6 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
 
 def get_schedule_by_suburb_id(provider: Provider, province: Province, suburb_id: int, stage: Stage = None, cached: bool = True) -> Dict[int, list]:
     suburb = Suburb(id=suburb_id)
-    # if province is None:
-    #     try:
-    #         info = provider.get_schedule_area_info(suburb_id=suburb_id)
-    #         province = info.province
-    #         suburb = info.suburb
-    #     except ProviderError as e:
-    #         logging.log(logging.ERROR, "Unable to get suburb info from {provider}. {e}".format(provider=provider, e=e))
-    #         raise e
     try:
         schedule = get_schedule(provider, province=province, suburb=suburb, stage=stage, cached=cached)
     except ScheduleError as e:
